# python-ximalaya

Python package for Ximalaya services.

## License

Copyright (C) 2024 Garrett HE <garrett.he@outlook.com>

The GNU General Public License (GPL) version 3, see [COPYING](./COPYING).
